////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
material mtl_specular
{
	effect = 
	"///////////////////////////////////////////////////////////////////////////////////////////////////////////
	//Simple Specular shader
	//Roel Smit
	///////////////////////////////////////////////////////////////////////////////////////////////////////////
	//variables
	float4x4 matWorldViewProj;
	float4x4 matWorld;
	float4 vecSunDir;
	float4 vecViewPos;
	float4 vecAmbient;
	float4 vecSpecular;
	//textures
	texture entSkin1;
	texture entSkin2;
	///////////////////////////////////////////
	//samplers
	sampler ColorMap = sampler_state
	{
		texture = <entSkin1>;
		AddressU = wrap;
		AddressV = wrap;
	};
	///////////////////////////////////////////
	//structs
	struct VertexIn
	{
		float4 Pos 			: POSITION;
		float3 Normal		: NORMAL;
		float2 Texc			: TEXCOORD;
	};
	struct PixelIn
	{
		float4 Pos 			: POSITION;
		float2 Texc			: TEXCOORD0;
		float3 Normal		: TEXCOORD1;
		float3 vecViewDir : TEXCOORD2;
		float3 vecSunDir	: TEXCOORD3;
	};
	///////////////////////////////////////////////////////////////////////////////////////////////////////////
	//vertex shader
	void MainVS_1_1(in VertexIn Input,out PixelIn Output)
	{
		Output.Pos = mul(Input.Pos,matWorldViewProj);
		Output.Texc = Input.Texc;
		Output.Normal = round(mul(Input.Normal,matWorld));
		Output.vecViewDir = normalize(vecViewPos - mul(Input.Pos ,matWorld));
		Output.vecSunDir = normalize(-vecSunDir);
	}
	//pixel shader
	float4 MainPS_2_0(in PixelIn Input) : COLOR
	{
		float4 Color = tex2D(ColorMap,Input.Texc);
		half Specular = saturate(dot(reflect(Input.vecViewDir,Input.Normal),Input.vecSunDir))*Color;
		half Shadow = saturate(dot(Input.Normal,Input.vecSunDir));
		float4 ReturnValue = (Shadow+Specular*0.5+vecAmbient) * Color;
		return ReturnValue;
	}
	///////////////////////////////////////////////////////////////////////////////////////////////////////////
	//techniques
	technique DefaultTech
	{
		pass p0
		{
			VertexShader = compile vs_1_1 MainVS_1_1();
			PixelShader  = compile ps_2_0 MainPS_2_0();
		}	
	}
	technique FallBack
	{
		pass p0
		{
		}
	}
	";
}